import { Component, OnInit } from '@angular/core';
import {FormArray, FormControl, FormGroup, NgForm} from '@angular/forms';
import {DataService} from '../services/data.service';
import {ModulesModel} from '../models/modules.model';
import {DataModel, VariablesName} from '../models/data.model';
import {GraphDataModel, GraphSetting} from '../models/graphData.model';

@Component({
  selector: 'app-history',
  templateUrl: './history.component.html',
  styleUrls: ['./history.component.scss']
})
export class HistoryComponent implements OnInit {

  Modules: ModulesModel[];
  Data: DataModel[];
  VariablesName = VariablesName;

  graphData: GraphDataModel[] = [];

  setting: GraphSetting = new GraphSetting();
  selectedVariables: string[] = [];
  moduleData: DataModel[];
  numberOfRecords;
  selectedModule: number;

  loaded = false;

  constructor(private ds: DataService) { }

  ngOnInit(): void {
    this.ds.getModules().subscribe( data => {
      this.Modules = data.filter( el => el.type != 'hub');

      this.selectedModule = this.Modules[0].id;
      this.changeGraph();
    });
    this.ds.getData().subscribe( data => {
      this.Data = data
      this.numberOfRecords = data.length;
    });
  }

  getKeys = (obj: DataModel) => Object.keys(obj)

  changeGraph(form?: FormGroup){
    this.loaded = false;
    this.ds.getDataById(this.selectedModule).subscribe( data => {
      this.setting.variables = this.getKeys(data[0]);
      this.setting.variables.splice(0, 2);
      this.moduleData = data;
      this.numberOfRecords = data.length;
      this.getGraphData();
      this.loaded = true;
    })
  }

  dateTickFormatting(val: any): String {
    if (val instanceof Date) {
      return (<Date>val).toLocaleTimeString([], {hour: '2-digit', minute:'2-digit'}) + " " + (<Date>val).toLocaleDateString();
    }
  }

  isChecked(name){
    return this.selectedVariables.includes(name);
  }

  onCheckboxChange(e) {
    if (e.target.checked) {
      this.selectedVariables.push(e.target.value);
    } else {
      this.selectedVariables.forEach((item) => {
        if (item == e.target.value) {
          this.selectedVariables.splice(this.selectedVariables.findIndex(el => el == e.target.value), 1);
          return;
        }
      });
    }

    this.getGraphData();
  }

  getGraphData(){
    this.graphData = [];

    for (let variable of this.selectedVariables){
      let data = Array();
      this.moduleData = this.moduleData.reverse();
      let i = 0;
      for (let module of this.moduleData){
        if (module.hasOwnProperty(variable)){
          if (i >= this.numberOfRecords){
            break;
          }
          data.push({name: new Date(module.time), value: module[variable]})
          i++;
        }
      }
      this.graphData.push({name: VariablesName[variable], series: data});
    }
  }

  getLocaleDate(date: string){
    return new Date(date).toLocaleTimeString([], {hour: '2-digit', minute:'2-digit'}) + " " + new Date(date).toLocaleDateString();
  }

  print(dat){
    console.log(dat)
  }


}
