import {Component, OnInit, TemplateRef} from '@angular/core';
import {DataService} from '../services/data.service';
import {ModulesModel} from '../models/modules.model';
import {BsModalRef, BsModalService} from 'ngx-bootstrap/modal';
import {SettingsService} from '../services/settings.service';

@Component({
  selector: 'app-setting',
  templateUrl: './setting.component.html',
  styleUrls: ['./setting.component.scss']
})
export class SettingComponent implements OnInit {

  modules: ModulesModel[];

  modalRef: BsModalRef;
  modalModule: ModulesModel;
  modalName: string;

  constructor(private ds: DataService,
              private ss: SettingsService,
              private modalService: BsModalService) { }

  ngOnInit(): void {
    this.ds.getModules().subscribe( data => {
      this.modules = data;
    })
  }

  confirmChangeName(){
    const changed = this.modules.find(el => el.id == this.modalModule.id);
    changed.name = this.modalName;
    this.ss.changeModuleName(this.modules);
    this.modalRef.hide();
  }

  resetWifiConnection(){
    this.ss.resetWifiConnection(this.modalModule);
    this.modalRef.hide();
  }

  resetMeasuredData(){
    this.ss.resetMeasuredData();
    this.modalRef.hide();
  }

  resetAllData(){
    this.ss.resetAllData();
    this.modalRef.hide();
  }

  deleteModule(){
    const index = this.modules.findIndex(el => el.id == this.modalModule.id);
    this.modules.splice(index, 1);
    this.ss.deleteModule(this.modules, this.modalModule);
    this.modalRef.hide();
  }

  openModal(template: TemplateRef<any>, module: ModulesModel) {
    this.modalModule = module;
    this.modalName = module.name;
    this.modalRef = this.modalService.show(template);
  }

}
